@@ -224,7 +224,8 @@ namespace LibCECTray.controller.applications
     {
       var keyName = Enum.GetName(typeof(VirtualKeyCode), key).ToUpper();
       var friendlyName = Resources.ResourceManager.GetString(keyName, Resources.Culture);
-      return friendlyName ?? keyName.ToLower().Substring(3).Replace('_', ' ');
+      var rv = friendlyName ?? keyName.ToLower().Substring(3).Replace('_', ' ');
+      return (rv.Length == 1) ? rv.ToUpper() : rv;
     }
 
     public enum InputType : uint
@@ -414,9 +415,12 @@ namespace LibCECTray.controller.applications
     /// <returns>True when sent false otherwise</returns>
     public static bool SendInputTo(IntPtr windowHandle, uint numberOfInputs, Input[] input, int structSize)
     {
-      return ShowWindowAsync(windowHandle, (int)ShowType.ShowNormal) &&
-             ForceForeground(windowHandle) &&
-             SendInput(numberOfInputs, input, structSize) == 0;
+      if (windowHandle != IntPtr.Zero)
+      {
+          if (ShowWindowAsync(windowHandle, (int)ShowType.ShowNormal) || ForceForeground(windowHandle))
+              return false;
+      }
+      return SendInput(numberOfInputs, input, structSize) > 0;
     }
 
     /// <summary>
